﻿unit UdmMain;

interface

uses
  System.SysUtils, System.Classes, Data.DB, Datasnap.DBClient, Vcl.Dialogs,
  ppBands, ppCache, ppClass, ppDB, ppDesignLayer, ppParameter, ppProd, ppReport,
  ppComm, ppRelatv, ppDBPipe, ppTypes, ppCtrls, ppVar, ppRichView, ppPrnabl,
  ppStrtch, ppMemo, RVGrHandler, RVFuncs, RVTypes;

type
  TdmMain = class(TDataModule)
    cdsData: TClientDataSet;
    cdsDataID: TIntegerField;
    cdsDataPatient: TStringField;
    cdsDataText: TMemoField;
    dsData: TDataSource;
    ppDBData: TppDBPipeline;
    ppReport: TppReport;
    ppParameterList1: TppParameterList;
    dlgOpen: TOpenDialog;
    ppDesignLayers1: TppDesignLayers;
    ppDesignLayer1: TppDesignLayer;
    ppHeaderBand1: TppHeaderBand;
    ppDetailBand1: TppDetailBand;
    ppFooterBand1: TppFooterBand;
    procedure DataModuleCreate(Sender: TObject);
  private
    { Private declarations }
  public
    function LoadDocument: Boolean;
    procedure PrintReport(ARichViewRep: Boolean);
    { Public declarations }
  end;

var
  dmMain: TdmMain;

implementation

uses
  Vcl.Forms, System.IOUtils, System.UITypes;

{%CLASSGROUP 'Vcl.Controls.TControl'}

{$R *.dfm}

procedure TdmMain.DataModuleCreate(Sender: TObject);
begin
  cdsData.CreateDataSet;
  cdsData.Append;
  cdsDataID.AsInteger := 1;
  cdsDataPatient.AsString := 'John Smith';
  cdsData.Post;
end;

function TdmMain.LoadDocument: Boolean;
var
  sTemp : String;
begin
  Result := False;
  with dlgOpen do
  begin
    Title := 'Choose document';
    Filter := 'RichTextFile (rtf)|*.rtf|' +
              'All files|*.*|';
    InitialDir := ExtractFilePath(ParamStr(0));
    FileName := ExtractFilePath(ParamStr(0)) + 'Document.rtm';
    if Execute then
    begin
      sTemp := TFile.ReadAllText(dlgOpen.FileName);
      cdsData.Edit;
      cdsDataText.AsString := sTemp;
      Result := True;
    end;
  end;
end;

procedure TdmMain.PrintReport(ARichViewRep: Boolean);
var
  sReport : String;
begin
  if not ARichViewRep then
    sReport := IncludeTrailingPathDelimiter(ExtractFilePath(ParamStr(0))) + 'Document.rtm'
  else
    sReport := IncludeTrailingPathDelimiter(ExtractFilePath(ParamStr(0))) + 'DocumentRV.rtm';

  if not FileExists(sReport) then
  begin
    MessageDlg(Format('Unable to find report %s.', [sReport]), mtWarning, [mbOK], 0);
    Exit;
  end;

  with ppReport do
  begin
    Template.FileName := sReport;
    Template.LoadFromFile;

    DeviceType                      := 'Screen';
    UseLegacyPrinterDialog          := True;
    AllowPrintToFile                := True;
    TextFileName                    := ChangeFileExt(sReport, '.raf');
    PreviewFormSettings.WindowState := TWindowState.wsNormal;
    PreviewFormSettings.ZoomSetting := zs100percent;
    SavePrinterSetup                := True;

    PDFSettings.Author              := 'Goran';
    PDFSettings.Subject             := 'Test document';
    PDFSettings.Title               := 'Test document';
    PDFSettings.EmbedFontOptions    := [efAllFonts, efUseSubset];
    PDFSettings.FontEncoding        := feUnicode;
    PDFSettings.OpenPDFFile         := True;
    PDFSettings.ScaleImages         := False;

    //LanguageID                 := cRBLanguageSLO;
    OutlineSettings.Enabled         := False;
    OutlineSettings.Visible         := False;
    TextSearchSettings.Enabled      := False;
    ThumbnailSettings.Enabled       := False;
    ThumbnailSettings.Visible       := False;

    Print;
  end;
end;

end.
